public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH-2.6.0-test5-mm1] conversion of schedule_task to schedule_work
@ 2003-09-11 11:02 Krishnakumar. R
  0 siblings, 0 replies; only message in thread
From: Krishnakumar. R @ 2003-09-11 11:02 UTC (permalink / raw)
  To: Andrew Morton; +Cc: linux-kernel

Hi,

The following patch converts one 'schedule_task'
in the code, and one 'schedule_task' in a comment
to 'schedule_work'. The file changed is drivers/char/istallion.c
The patch applies against 2.6.0-test5-mm1.

Regards
KK

============================
Compilation Warning removed:
drivers/char/istallion.c:2947: warning: implicit declaration of function `schedule_task'
drivers/char/istallion.c: In function `stli_startbrd':

Linking warning removed:
drivers/built-in.o(.text+0x25e73): In function `stli_poll':
: undefined reference to `schedule_task'

=============================
diffstat output:

istallion.c |    4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)

=============================
The following is the patch:

--- linux-2.6.0-test5-mm1/drivers/char/istallion.orig.c	2003-09-11 14:51:35.000000000 +0530
+++ linux-2.6.0-test5-mm1/drivers/char/istallion.c	2003-09-11 14:52:06.000000000 +0530
@@ -2303,7 +2303,7 @@
 
 	/*
 	 * FIXME: There's a module removal race here: tty_hangup
 	 * calls schedule_task which will call into this
 	 * driver later.
 	 */
 	portp = (stliport_t *) arg;
@@ -2944,7 +2944,7 @@
 			    ((portp->sigs & TIOCM_CD) == 0)) {
 				if (portp->flags & ASYNC_CHECK_CD) {
 					if (tty)
-						schedule_task(&portp->tqhangup);
+						schedule_work(&portp->tqhangup);
 				}
 			}
 		}





^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2003-09-11 10:58 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -2303,7 +2303,7 @@
 	/*
 	 * FIXME: There's a module removal race here: tty_hangup
-	 * calls schedule_task which will call into this
+	 * calls schedule_work which will call into this
 	 * driver later.
 	 */
2003-09-11 11:02 [PATCH-2.6.0-test5-mm1] conversion of schedule_task to schedule_work Krishnakumar. R

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox